use dioxus::prelude::{dioxus_elements::FileEngine, *};
use std::sync::Arc;

#[derive(Debug)]
struct UploadedFile {
    name: String,
    contents: String,
}

#[component]
pub fn Migration() -> Element {
    let mut file_uploaded = use_signal(|| None);

    let read_files = move |file_engine: Arc<dyn FileEngine>| async move {
        let files = file_engine.files();
        for file_name in &files {
            if let Some(contents) = file_engine.read_file_to_string(file_name).await {
                file_uploaded.set(Some(UploadedFile {
                    name: file_name.clone(),
                    contents,
                }));
            }
        }
    };

    let upload_files = move |evt: FormEvent| async move {
        if let Some(file_engine) = evt.files() {
            read_files(file_engine).await;
        }
    };

    let sumbit = move |_evt: FormEvent| async move {
        match &*file_uploaded.read() {
            Some(file) => {
                if let Ok(_response) = upload_members_list(file.contents.clone()).await {
                    tracing::info!("Loaded!!");
                }
            }
            None => tracing::info!("File doesn't exists"),
        }
    };
    rsx! {
        div {
            class: "flex flex-col items-center justify-center h-full py-10",
            ul {
                class: "steps pb-16",
                li { class: "step step-primary", "Uploaden" },
                li { class: "step", "Controleren" },
                li { class: "step", "Klaar" },
            }
            form {
                class: "flex flex-col items-center w-full h-full max-w-md mx-auto px-2",
                onsubmit: sumbit,
                h2 { class: "text-xl", "Selecteer het ledenbestand" },
                input {
                    r#type: "file",
                    class: "file-input file-input-bordered w-full mt-16",
                    accept: ".csv",
                    multiple: false,
                    autocomplete: false,
                    onchange: upload_files,
                }
                input {
                    r#type: "submit",
                    class: "btn btn-primary btn-wide mt-5",
                    disabled: file_uploaded.read().is_none(),
                    value: "Uploaden"
                }
            }
        }
    }
}

#[server]
async fn upload_members_list(input: String) -> Result<String, ServerFnError> {
    tracing::info!("Getting members...");
    Ok("Whoo".to_string())
}
